@@ -1,8 +1,8 @@
 # Configuration file for the Sphinx documentation builder.
 #
-# This file only contains a selection of the most common options. For a full
-# list see the documentation:
-# https://www.sphinx-doc.org/en/master/usage/configuration.html
+# This file does only contain a selection of the most common options. For a
+# full list see the documentation:
+# http://www.sphinx-doc.org/en/master/config
 
 # -- Path setup --------------------------------------------------------------
 
@@ -13,16 +13,22 @@
 # import os
 # import sys
 # sys.path.insert(0, os.path.abspath('.'))
-
+from pcrunner import __version__
 
 # -- Project information -----------------------------------------------------
 
 project = 'Passive Check Runner'
-copyright = '2021, Maarten'
+copyright = '2021, Maarten'  # noqa: A001
 author = 'Maarten'
 
+# The short X.Y version
+version = __version__
+
 # The full version, including alpha/beta/rc tags
-release = '0.4.9'
+try:
+    release = '.'.join(__version__.split('.')[:2])
+except Exception:
+    release = __version__
 
 
 # -- General configuration ---------------------------------------------------
