@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # scripts/check_dummy.py
 # vim: ai et ts=4 sw=4 sts=4 ft=python fileencoding=utf-8
 
@@ -16,10 +16,10 @@ def main(args):
         if args.sleep:
             time.sleep(args.sleep)
         if args.text:
-            print((args.text))
+            print(args.text)
         sys.exit(args.exitcode)
     else:
-        raise Exception('exit code should be >= 0 and < 4')
+        raise Exception('exit code should be >= 0 and < 4')  # noqa: TRY002
 
 
 def parse_args(args):
